<?php
# dvdisaster: English homepage dictionary
# Copyright (C) 2004-2012 Carsten Gnörlich
#
# UTF-8 trigger: äöüß 

# English dictionary for some phrases used in dvdisaster.php

$trans_version="Version";

$trans_to_internet="To the Internet version";
$trans_to_hoster="Summary (at SourceForge.net)";

$trans_back="Back";
$trans_screen_shot="Screen shot";

$trans_contents="Contents";
$trans_news="News";
$trans_atom_title="dvdisaster news";
$trans_hosting="Hosted by";

$trans_fdl="Verbatim copying and distribution of this entire article is permitted in any medium, provided this notice is preserved.";
$trans_copyright="Copyright 2004-2012 Carsten Gnörlich.";

$trans_sourcecode="Source code for all operating systems:";
$trans_signature="Digital signature:";
$trans_md5="MD5 checksum:";
$trans_macbinary="Binary for Mac OS X 10.5 / x86:";
$trans_winbinary="Binary for Windows:";
?>